@@ -37,9 +37,7 @@
 
 #include "nettle-meta.h"
 
-#undef nettle_aeads
-
-const struct nettle_aead * const nettle_aeads[] = {
+const struct nettle_aead * const _nettle_aeads[] = {
   &nettle_gcm_aes128,
   &nettle_gcm_aes192,
   &nettle_gcm_aes256,
@@ -53,5 +51,5 @@ const struct nettle_aead * const nettle_aeads[] = {
 const struct nettle_aead * const *
 nettle_get_aeads (void)
 {
-  return nettle_aeads;
+  return _nettle_aeads;
 }
